SignatureResult class

Result object from signature generation

Constructors

SignatureResult({required dynamic timestamp, required String nonce, required String signature, required String algorithm, required String encoding, required String canonicalString})
const

Properties

algorithm String
Hash algorithm used
final
canonicalString String
The canonical string that was signed (for debugging)
final
encoding String
Encoding format used
final
hashCode int
The hash code for this object.
no setterinherited
nonce String
Generated nonce
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String
HMAC signature
final
timestamp → dynamic
Generated timestamp
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited