VerificationResult class

Result from signature verification

Constructors

VerificationResult({required bool valid, String? error, String? expected, String? received, required int timestampAge})
const

Properties

error String?
Error message if invalid
final
expected String?
Expected signature (for debugging)
final
hashCode int
The hash code for this object.
no setterinherited
received String?
Received signature (for debugging)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampAge int
Age of timestamp in milliseconds
final
valid bool
Whether signature is valid
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited