HmacConfig class
Configuration options for signature generation
- Implementers
Constructors
-
HmacConfig({String signatureMethod = 'canonical', String separator = '|', List<
String> ? canonicalFields, String hashAlgorithm = 'sha256', String encoding = 'hex', String timestampFormat = 'milliseconds', String nonceFormat = 'uuid-v4', String customNonceGenerator()?, dynamic customTimestamp, String? customNonce, bool includeTimestampInSignature = true, bool includeNonceInSignature = true, bool sortJsonKeys = true}) -
const
Properties
-
canonicalFields
→ List<
String> ? -
Explicit field order for canonical signing
final
- customNonce → String?
-
Custom nonce (for testing)
final
- customNonceGenerator → String Function()?
-
Custom nonce generator function
final
- customTimestamp → dynamic
-
Custom timestamp (for testing)
final
- encoding → String
-
Output encoding: 'hex', 'base64', 'base64url'
final
- hashAlgorithm → String
-
Hash algorithm: 'sha256', 'sha512', 'sha384', 'sha1', 'md5'
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeNonceInSignature → bool
-
Include nonce in signature payload
final
- includeTimestampInSignature → bool
-
Include timestamp in signature payload
final
- nonceFormat → String
-
Nonce format: 'uuid-v4', 'uuid-v1', 'random-hex', 'random-base64', 'custom'
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separator → String
-
Separator for canonical string (default: '|')
final
- signatureMethod → String
-
Signature method: 'canonical' or 'json'
final
- sortJsonKeys → bool
-
Sort JSON keys when using 'json' method
final
- timestampFormat → String
-
Timestamp format: 'milliseconds', 'seconds', 'unix', 'iso8601'
final
Methods
-
copyWith(
{String? signatureMethod, String? separator, List< String> ? canonicalFields, String? hashAlgorithm, String? encoding, String? timestampFormat, String? nonceFormat, String customNonceGenerator()?, dynamic customTimestamp, String? customNonce, bool? includeTimestampInSignature, bool? includeNonceInSignature, bool? sortJsonKeys}) → HmacConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited