HmacOperations class
HmacOperations class for generating and verifying HMAC signatures
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateSignature(
Map< String, dynamic> payload, String secretKey, {HmacConfig config = const HmacConfig()}) → SignatureResult - Generate HMAC signature with timestamp and nonce for API authentication
-
verifySignature(
Map< String, dynamic> payload, String secretKey, String receivedSignature, dynamic receivedTimestamp, String receivedNonce, {VerificationConfig config = const VerificationConfig()}) → VerificationResult - Verify a signature against expected values