VerificationConfig class
Configuration for signature verification
- Inheritance
-
- Object
- HmacConfig
- VerificationConfig
Constructors
-
VerificationConfig({String signatureMethod = 'canonical', String separator = '|', List<
String> ? canonicalFields, String hashAlgorithm = 'sha256', String encoding = 'hex', String timestampFormat = 'milliseconds', String nonceFormat = 'uuid-v4', String customNonceGenerator()?, dynamic customTimestamp, String? customNonce, bool includeTimestampInSignature = true, bool includeNonceInSignature = true, bool sortJsonKeys = true, int timestampTolerance = 180000}) -
const
Properties
-
canonicalFields
→ List<
String> ? -
Explicit field order for canonical signing
finalinherited
- customNonce → String?
-
Custom nonce (for testing)
finalinherited
- customNonceGenerator → String Function()?
-
Custom nonce generator function
finalinherited
- customTimestamp → dynamic
-
Custom timestamp (for testing)
finalinherited
- encoding → String
-
Output encoding: 'hex', 'base64', 'base64url'
finalinherited
- hashAlgorithm → String
-
Hash algorithm: 'sha256', 'sha512', 'sha384', 'sha1', 'md5'
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeNonceInSignature → bool
-
Include nonce in signature payload
finalinherited
- includeTimestampInSignature → bool
-
Include timestamp in signature payload
finalinherited
- nonceFormat → String
-
Nonce format: 'uuid-v4', 'uuid-v1', 'random-hex', 'random-base64', 'custom'
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separator → String
-
Separator for canonical string (default: '|')
finalinherited
- signatureMethod → String
-
Signature method: 'canonical' or 'json'
finalinherited
- sortJsonKeys → bool
-
Sort JSON keys when using 'json' method
finalinherited
- timestampFormat → String
-
Timestamp format: 'milliseconds', 'seconds', 'unix', 'iso8601'
finalinherited
- timestampTolerance → int
-
Allowed timestamp age in milliseconds (default: 180000 = 3 minutes)
final
Methods
-
copyWith(
{String? signatureMethod, String? separator, List< String> ? canonicalFields, String? hashAlgorithm, String? encoding, String? timestampFormat, String? nonceFormat, String customNonceGenerator()?, dynamic customTimestamp, String? customNonce, bool? includeTimestampInSignature, bool? includeNonceInSignature, bool? sortJsonKeys}) → HmacConfig -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited